==> 0.1.0.tar.gz: android/src/main/kotlin/qiuxiang/tencent_map/TencentMapPlugin.kt <==
package qiuxiang.tencent_map

import androidx.annotation.NonNull
import com.tencent.tencentmap.mapsdk.maps.TencentMapInitializer

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** TencentMapPlugin */
class TencentMapPlugin : FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel: MethodChannel

  override fun onAttachedToEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(binding.binaryMessenger, "tencent_map")
    channel.setMethodCallHandler(this)
    binding.platformViewRegistry.registerViewFactory("tencent_map", TencentMapFactory())
    TencentMapInitializer.setAgreePrivacy(true)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}

==> 0.2.0.tar.gz: android/src/main/kotlin/qiuxiang/tencent_map/TencentMapPlugin.kt <==
package qiuxiang.tencent_map

import androidx.annotation.NonNull
import com.tencent.tencentmap.mapsdk.maps.TencentMapInitializer
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** TencentMapPlugin */
class TencentMapPlugin : FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel: MethodChannel

  override fun onAttachedToEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(binding.binaryMessenger, "tencent_map")
    channel.setMethodCallHandler(this)
    binding.platformViewRegistry.registerViewFactory("tencent_map", TencentMapFactory(binding.binaryMessenger))
    TencentMapInitializer.setAgreePrivacy(true)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "getPlatformVersion") {
      result.success("Android ${android.os.Build.VERSION.RELEASE}")
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}
